summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorYuri Chornoivan <yurchor@ukr.net>2013-10-19 17:38:00 +0300
committerDan Winship <danw@gnome.org>2013-10-19 11:49:18 -0400
commit61de24ba35b452c82ec6f672f62e78feae524e7c (patch)
tree62fec8f514036c7dea06268a60576e80591dfa3f
parent72da550f68c88d7c3a7836673de950dd61e05dab (diff)
downloadNetworkManager-61de24ba35b452c82ec6f672f62e78feae524e7c.tar.gz
Fix typos
https://bugzilla.gnome.org/show_bug.cgi?id=710505
-rw-r--r--cli/src/connections.c12
-rw-r--r--cli/src/settings.c4
-rw-r--r--docs/NetworkManager DBUS API.txt2
-rw-r--r--libnm-glib/nm-device.c2
-rw-r--r--libnm-glib/nm-remote-settings.c2
-rw-r--r--libnm-glib/nm-vpn-plugin-ui-interface.h2
-rw-r--r--libnm-util/nm-connection.c2
-rw-r--r--man/nmcli-examples.xml2
-rw-r--r--man/nmcli.1.in2
-rw-r--r--src/devices/nm-device-wifi.c2
-rw-r--r--src/platform/tests/test-common.c2
-rw-r--r--src/rdisc/nm-lndp-rdisc.c2
-rw-r--r--src/settings/plugins/example/plugin.c2
-rw-r--r--src/settings/plugins/ifnet/tests/net.all4
-rw-r--r--src/vpn-manager/nm-vpn-service.c2
15 files changed, 22 insertions, 22 deletions
diff --git a/cli/src/settings.c b/cli/src/settings.c
index 81e8779e5a..f504b89f2e 100644
--- a/cli/src/settings.c
+++ b/cli/src/settings.c
@@ -2910,8 +2910,8 @@ nmc_property_ipv6_describe_dns (NMSetting *setting, const char *prop)
"configuration method is 'auto' these DNS servers are appended "
"to those (if any) returned by automatic configuration. DNS "
"servers cannot be used with the 'shared' or 'link-local' IPv6 "
- "configuration methods, as there is no usptream network. In "
- "all other IPv6 configuration methods methods, these DNS "
+ "configuration methods, as there is no upstream network. In "
+ "all other IPv6 configuration methods, these DNS "
"servers are used as the only DNS servers for this connection.\n\n"
"Example: 2607:f0d0:1002:51::4, 2607:f0d0:1002:51::1\n");
}
diff --git a/docs/NetworkManager DBUS API.txt b/docs/NetworkManager DBUS API.txt
index 7a614348f3..0a12c2674e 100644
--- a/docs/NetworkManager DBUS API.txt
+++ b/docs/NetworkManager DBUS API.txt
@@ -103,7 +103,7 @@ The Device object is the NM representation of a network device. To refer to a N
DBUS Service: "org.freedesktop.NetworkManager"
DBUS Interface: "org.freedesktop.NetworkManager.Devices"
-Note that there is no DBUS Object Path listed above, the object path will always the the NM Device identfier returned from such methods as "getActiveDevice" and "getDevices".
+Note that there is no DBUS Object Path listed above, the object path will always the NM Device identfier returned from such methods as "getActiveDevice" and "getDevices".
Methods:
diff --git a/libnm-glib/nm-device.c b/libnm-glib/nm-device.c
index f03d47cf71..05e59e504e 100644
--- a/libnm-glib/nm-device.c
+++ b/libnm-glib/nm-device.c
@@ -1454,7 +1454,7 @@ _get_udev_property (NMDevice *device,
/* Balance the initial g_udev_client_query_by_subsystem_and_name() */
g_object_unref (udev_device);
- /* Prefer the the encoded value which comes directly from the device
+ /* Prefer the encoded value which comes directly from the device
* over the hwdata database value.
*/
if (enc_value) {
diff --git a/libnm-glib/nm-remote-settings.c b/libnm-glib/nm-remote-settings.c
index 589d755653..1dbbbb832b 100644
--- a/libnm-glib/nm-remote-settings.c
+++ b/libnm-glib/nm-remote-settings.c
@@ -679,7 +679,7 @@ clear_one_hash (GHashTable *table)
/* Build up the list of connections; we can't emit "removed" during hash
* table iteration because emission of the "removed" signal may trigger code
- * that explicitly removes the the connection from the hash table somewhere
+ * that explicitly removes the connection from the hash table somewhere
* else.
*/
g_hash_table_iter_init (&iter, table);
diff --git a/libnm-glib/nm-vpn-plugin-ui-interface.h b/libnm-glib/nm-vpn-plugin-ui-interface.h
index 068d8f89fa..3c611a2a8c 100644
--- a/libnm-glib/nm-vpn-plugin-ui-interface.h
+++ b/libnm-glib/nm-vpn-plugin-ui-interface.h
@@ -68,7 +68,7 @@ typedef enum /*< flags >*/ {
/* Short display name of the VPN plugin */
#define NM_VPN_PLUGIN_UI_INTERFACE_NAME "name"
-/* Longer description of the the VPN plugin */
+/* Longer description of the VPN plugin */
#define NM_VPN_PLUGIN_UI_INTERFACE_DESC "desc"
/* D-Bus service name of the plugin's VPN service */
diff --git a/libnm-util/nm-connection.c b/libnm-util/nm-connection.c
index 1cd81db5e5..01223daf62 100644
--- a/libnm-util/nm-connection.c
+++ b/libnm-util/nm-connection.c
@@ -263,7 +263,7 @@ nm_connection_get_setting (NMConnection *connection, GType setting_type)
* @name: a setting name
*
* Gets the #NMSetting with the given name, if one has been previously added
- * the the #NMConnection.
+ * the #NMConnection.
*
* Returns: (transfer none): the #NMSetting, or %NULL if no setting with that name was previously
* added to the #NMConnection
diff --git a/man/nmcli-examples.xml b/man/nmcli-examples.xml
index 29430f13fa..c45d69a995 100644
--- a/man/nmcli-examples.xml
+++ b/man/nmcli-examples.xml
@@ -350,7 +350,7 @@ ipv4.may-fail: yes
nmcli> verify
Verify connection: OK
nmcli> save
-Connection 'ethernet-4' (de89cdeb-a3e1-4d53-8fa0-c22546c775f4) sucessfully saved.
+Connection 'ethernet-4' (de89cdeb-a3e1-4d53-8fa0-c22546c775f4) successfully saved.
nmcli> quit
</screen>
</example>
diff --git a/man/nmcli.1.in b/man/nmcli.1.in
index c80c40981e..cc3bd492e1 100644
--- a/man/nmcli.1.in
+++ b/man/nmcli.1.in
@@ -556,7 +556,7 @@ If <ID> is ambiguous, a keyword \fIid\fP, \fIuuid\fP, or \fIpath\fP can be used.
See \fBshow active\fP above for the description of the <ID>-specifying keywords.
Not providing an <ID> means that a new connection will be added.
.sp
-The interactive editor will guide you through the connection editation and
+The interactive editor will guide you through the connection editing and
allow you to change connection parameters according to your needs by means of
a simple menu-driven interface. The editor indicates what settings and
properties can be modified and provides an inline help.
diff --git a/src/devices/nm-device-wifi.c b/src/devices/nm-device-wifi.c
index 6a3e69a402..164843afaa 100644
--- a/src/devices/nm-device-wifi.c
+++ b/src/devices/nm-device-wifi.c
@@ -706,7 +706,7 @@ periodic_update (gpointer user_data)
/* In IBSS mode, most newer firmware/drivers do "BSS coalescing" where
* multiple IBSS stations using the same SSID will eventually switch to
* using the same BSSID to avoid network segmentation. When this happens,
- * the card's reported BSSID will change, but the the new BSS may not
+ * the card's reported BSSID will change, but the new BSS may not
* be in the scan list, since scanning isn't done in ad-hoc mode for
* various reasons. So pull the BSSID from the card and update the
* current AP with it, if the current AP is adhoc.
diff --git a/src/platform/tests/test-common.c b/src/platform/tests/test-common.c
index ea9a4af09c..5911cce9fa 100644
--- a/src/platform/tests/test-common.c
+++ b/src/platform/tests/test-common.c
@@ -71,7 +71,7 @@ link_callback (NMPlatform *platform, int ifindex, NMPlatformLink *received, NMPl
if (data->received)
g_error ("Received signal '%s' a second time.", data->name);
- debug ("Recieved signal '%s' ifindex %d ifname '%s'.", data->name, ifindex, received->name);
+ debug ("Received signal '%s' ifindex %d ifname '%s'.", data->name, ifindex, received->name);
data->received = TRUE;
/* Check the data */
diff --git a/src/rdisc/nm-lndp-rdisc.c b/src/rdisc/nm-lndp-rdisc.c
index 3dbabbf6b8..14287c134f 100644
--- a/src/rdisc/nm-lndp-rdisc.c
+++ b/src/rdisc/nm-lndp-rdisc.c
@@ -444,7 +444,7 @@ receive_ra (struct ndp *ndp, struct ndp_msg *msg, gpointer user_data)
* single time when the configuration is finished and updates can
* come at any time.
*/
- debug ("Recieved router advertisement: %d at %d", rdisc->ifindex, (int) now);
+ debug ("Received router advertisement: %d at %d", rdisc->ifindex, (int) now);
if (priv->send_rs_id) {
g_source_remove (priv->send_rs_id);
diff --git a/src/settings/plugins/example/plugin.c b/src/settings/plugins/example/plugin.c
index 710ac752f3..18353a74e7 100644
--- a/src/settings/plugins/example/plugin.c
+++ b/src/settings/plugins/example/plugin.c
@@ -833,7 +833,7 @@ system_config_interface_init (NMSystemConfigInterface *sci_intf)
/*******************************************************************/
/* Factory function: this is the first entry point for NetworkManager, which
- * gets called during NM startup to create the the instance of this plugin
+ * gets called during NM startup to create the instance of this plugin
* that NetworkManager will actually use. Since every plugin is a singleton
* we just return a singleton instance. This function should never be called
* twice.
diff --git a/src/settings/plugins/ifnet/tests/net.all b/src/settings/plugins/ifnet/tests/net.all
index a30a1b95e6..285a4cdf2f 100644
--- a/src/settings/plugins/ifnet/tests/net.all
+++ b/src/settings/plugins/ifnet/tests/net.all
@@ -327,7 +327,7 @@ arping_wait_lan=2
# Please ensure your VLAN IDs are NOT zero-padded
vlans_eth0="1 2"
-# You may not want to assign an IP the the physical interface, but we still
+# You may not want to assign an IP to the physical interface, but we still
# need it up.
config_eth0=( "null" )
@@ -361,7 +361,7 @@ vlan_start_eth0="no"
# To bond interfaces together
slaves_bond0="eth0 eth1 eth2"
-config_bond0=( "null" ) # You may not want to assign an IP the the bond
+config_bond0=( "null" ) # You may not want to assign an IP to the bond
# If any of the slaves require extra configuration - for example wireless or
# ppp devices - we need to depend function on the bonded interfaces
diff --git a/src/vpn-manager/nm-vpn-service.c b/src/vpn-manager/nm-vpn-service.c
index 29b39faf18..a34c782e73 100644
--- a/src/vpn-manager/nm-vpn-service.c
+++ b/src/vpn-manager/nm-vpn-service.c
@@ -129,7 +129,7 @@ nm_vpn_service_connections_stop (NMVPNService *service,
GSList *iter, *copy;
/* Copy because stopping the connection may remove it from the list
- * in the the NMVPNService objects' VPN connection state handler.
+ * in the NMVPNService objects' VPN connection state handler.
*/
copy = g_slist_copy (priv->connections);
for (iter = copy; iter; iter = iter->next) {
diff --git a/cli/src/connections.c b/cli/src/connections.c
index fd06ca5547..e08bee8930 100644
--- a/cli/src/connections.c
+++ b/cli/src/connections.c
@@ -2675,7 +2675,7 @@ do_questionnaire_bond (char **mode, char **primary, char **miimon,
monitor_mode = g_strdup ("miimon");
once_more = strcmp (monitor_mode, "miimon") && strcmp (monitor_mode, "arp");
if (once_more) {
- printf (_("Error: '%s' is not a valid monitoring mode'; use '%s' or '%s'.\n"),
+ printf (_("Error: '%s' is not a valid monitoring mode; use '%s' or '%s'.\n"),
monitor_mode, "miimon", "arp");
g_free (monitor_mode);
}
@@ -4180,7 +4180,7 @@ cleanup_olpc:
} else {
g_set_error (error, NMCLI_ERROR, NMC_RESULT_ERROR_USER_INPUT,
- _("Error: '%s' is a not valid connection type."),
+ _("Error: '%s' is not a valid connection type."),
con_type);
return FALSE;
}
@@ -5180,7 +5180,7 @@ editor_main_help (const char *command)
switch (cmd) {
case NMC_EDITOR_MAIN_CMD_GOTO:
- printf (_("goto <setting>[.<prop>] | <prop> :: enter setting/property for editation\n\n"
+ printf (_("goto <setting>[.<prop>] | <prop> :: enter setting/property for editing\n\n"
"This command enters into a setting or property for editing it.\n\n"
"Examples: nmcli> goto connection\n"
" nmcli connection> goto secondaries\n"
@@ -5196,7 +5196,7 @@ editor_main_help (const char *command)
case NMC_EDITOR_MAIN_CMD_SET:
printf (_("set [<setting>.<prop> <value>] :: set property value\n\n"
"This command sets property value.\n\n"
- "Example: nmcli> s con.id My connection\n"));
+ "Example: nmcli> set con.id My connection\n"));
break;
case NMC_EDITOR_MAIN_CMD_DESCRIBE:
printf (_("describe [<setting>.<prop>] :: describe property\n\n"
@@ -5484,7 +5484,7 @@ editor_show_status_line (NMConnection *connection, gboolean dirty)
}
/*
* Submenu for detailed property editation
* Return: TRUE - continue; FALSE - should quit
*/
static gboolean
@@ -6289,7 +6289,7 @@ editor_menu_main (NmCli *nmc, NMConnection *connection, const char *connection_t
g_error_free (nmc_editor_error);
} else
- printf (_("Connection '%s' (%s) sucessfully saved.\n"),
+ printf (_("Connection '%s' (%s) successfully saved.\n"),
nm_connection_get_id (connection),
nm_connection_get_uuid (connection));
@@ -5484,7 +5484,7 @@ editor_show_status_line (NMConnection *connection, gboolean dirty)
}
/*
- * Submenu for detailed property editation
+ * Submenu for detailed property editing
* Return: TRUE - continue; FALSE - should quit
*/